==> haskell-split-0.2.3.3-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-split.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: split
version: 0.2.3.3
id: split-0.2.3.3-DYHuRk05Zl3FsXrGVgC4fG
key: split-0.2.3.3-DYHuRk05Zl3FsXrGVgC4fG
license: BSD-3-Clause
copyright: (c) Brent Yorgey, Louis Wasserman 2008-2012
maintainer: byorgey@gmail.com
author: Brent Yorgey
stability: stable
synopsis: Combinator library for splitting lists.
description:
    A collection of various methods for splitting
    lists into parts, akin to the \"split\" function
    found in several mainstream languages. Here is
    its tale:
    .
    Once upon a time the standard "Data.List" module
    held no function for splitting a list into parts
    according to a delimiter.  Many a brave
    lambda-knight strove to add such a function, but
    their striving was in vain, for Lo, the Supreme
    Council fell to bickering amongst themselves what
    was to be the essential nature of the One True
    Function which could cleave a list in twain (or
    thrain, or any required number of parts).
    .
    And thus came to pass the split package,
    comprising divers functions for splitting a list
    asunder, each according to its nature.  And the
    Supreme Council had no longer any grounds for
    argument, for the favored method of each was
    contained therein.
    .
    To get started, see the "Data.List.Split" module.
category: List
abi: cdf77c47c599317cfa01d2d98185c5d3
exposed: True
exposed-modules:
    Data.List.Split Data.List.Split.Internals
import-dirs: /usr/lib/ghc-8.4.3/site-local/split-0.2.3.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/split-0.2.3.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/split-0.2.3.3
hs-libraries: HSsplit-0.2.3.3-DYHuRk05Zl3FsXrGVgC4fG
depends:
    base-4.11.1.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
haddock-interfaces: /usr/share/doc/haskell-split/html/split.haddock
haddock-html: /usr/share/doc/haskell-split/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-split-0.2.3.3-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-split.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: split
version: 0.2.3.3
id: split-0.2.3.3-9O3ah5XNSacJuZjDAE6BjK
key: split-0.2.3.3-9O3ah5XNSacJuZjDAE6BjK
license: BSD-3-Clause
copyright: (c) Brent Yorgey, Louis Wasserman 2008-2012
maintainer: byorgey@gmail.com
author: Brent Yorgey
stability: stable
synopsis: Combinator library for splitting lists.
description:
    A collection of various methods for splitting
    lists into parts, akin to the \"split\" function
    found in several mainstream languages. Here is
    its tale:
    .
    Once upon a time the standard "Data.List" module
    held no function for splitting a list into parts
    according to a delimiter.  Many a brave
    lambda-knight strove to add such a function, but
    their striving was in vain, for Lo, the Supreme
    Council fell to bickering amongst themselves what
    was to be the essential nature of the One True
    Function which could cleave a list in twain (or
    thrain, or any required number of parts).
    .
    And thus came to pass the split package,
    comprising divers functions for splitting a list
    asunder, each according to its nature.  And the
    Supreme Council had no longer any grounds for
    argument, for the favored method of each was
    contained therein.
    .
    To get started, see the "Data.List.Split" module.
category: List
abi: 5a6de9e50fc8531285c090bfed58c923
exposed: True
exposed-modules:
    Data.List.Split Data.List.Split.Internals
import-dirs: /usr/lib/ghc-8.6.1/site-local/split-0.2.3.3
library-dirs: /usr/lib/ghc-8.6.1/site-local/split-0.2.3.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/split-0.2.3.3
hs-libraries: HSsplit-0.2.3.3-9O3ah5XNSacJuZjDAE6BjK
depends:
    base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-split/html/split.haddock
haddock-html: /usr/share/doc/haskell-split/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
